# mantium-spec
Mantium API Documentation

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.0.624
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonLegacyClientCodegen

## Requirements.

Python 2.7 and 3.4+

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import mantium_spec
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import mantium_spec
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python
from __future__ import print_function

import time
import mantium_spec
from mantium_spec.rest import ApiException
from pprint import pprint

# Defining the host is optional and defaults to http://localhost
# See configuration.py for a list of all supported configuration parameters.
configuration = mantium_spec.Configuration(
    host = "http://localhost"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure Bearer authorization: HTTPBearer
configuration = mantium_spec.Configuration(
    access_token = 'YOUR_BEARER_TOKEN'
)


# Enter a context with an instance of the API client
with mantium_spec.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = mantium_spec.ApplicationsApi(api_client)
    application_id = 'application_id_example' # str | 
body = None # object |  (optional)

    try:
        # Get application detail.
        api_response = api_instance.get_application_detail(application_id, body=body)
        pprint(api_response)
    except ApiException as e:
        print("Exception when calling ApplicationsApi->get_application_detail: %s\n" % e)
    
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ApplicationsApi* | [**get_application_detail**](docs/ApplicationsApi.md#get_application_detail) | **GET** /applications/{application_id} | Get application detail.
*ApplicationsApi* | [**list_applications**](docs/ApplicationsApi.md#list_applications) | **GET** /applications/ | List applications.
*ApplicationsApi* | [**query_application**](docs/ApplicationsApi.md#query_application) | **POST** /applications/{application_id}/query | Interact with an application.


## Documentation For Models

 - [Answer](docs/Answer.md)
 - [AnswerMeta](docs/AnswerMeta.md)
 - [ApplicationCredential](docs/ApplicationCredential.md)
 - [ApplicationDetailResponse](docs/ApplicationDetailResponse.md)
 - [ApplicationQueryRequest](docs/ApplicationQueryRequest.md)
 - [ApplicationQueryResponse](docs/ApplicationQueryResponse.md)
 - [ApplicationResponse](docs/ApplicationResponse.md)
 - [ApplicationStatus](docs/ApplicationStatus.md)
 - [ChatGPTPluginApplicationDetailResponse](docs/ChatGPTPluginApplicationDetailResponse.md)
 - [ContentCreationTemplateOptions](docs/ContentCreationTemplateOptions.md)
 - [ContentType](docs/ContentType.md)
 - [CredentialType](docs/CredentialType.md)
 - [CursorDatamodelPageApplicationResponse](docs/CursorDatamodelPageApplicationResponse.md)
 - [CustomTemplateOptions](docs/CustomTemplateOptions.md)
 - [CustomerSupportTemplateOptions](docs/CustomerSupportTemplateOptions.md)
 - [DataSourceType](docs/DataSourceType.md)
 - [Document](docs/Document.md)
 - [DocumentMetadata](docs/DocumentMetadata.md)
 - [EventPlanningTemplateOptions](docs/EventPlanningTemplateOptions.md)
 - [HTTPValidationError](docs/HTTPValidationError.md)
 - [LegalDocumentsTemplateOptions](docs/LegalDocumentsTemplateOptions.md)
 - [LocationInner](docs/LocationInner.md)
 - [MeetingInfoTemplateOptions](docs/MeetingInfoTemplateOptions.md)
 - [PersonalKnowledgeManagementTemplateOptions](docs/PersonalKnowledgeManagementTemplateOptions.md)
 - [ProductDocumentationTemplateOptions](docs/ProductDocumentationTemplateOptions.md)
 - [RecipeManagementTemplateOptions](docs/RecipeManagementTemplateOptions.md)
 - [ResponseGetApplicationDetail](docs/ResponseGetApplicationDetail.md)
 - [ShopifyTemplateOptions](docs/ShopifyTemplateOptions.md)
 - [Span](docs/Span.md)
 - [Template](docs/Template.md)
 - [ValidationError](docs/ValidationError.md)


## Documentation For Authorization


## HTTPBearer

- **Type**: Bearer authentication


## Author




